@@ -11,8 +11,8 @@ import time
 import sys
 
 
-class Zermelo:
-    def __init__(self, salureconnect_connection: SalureConnect, label: Union[str, List], storage_location, initial_zermelo_extract=False, extract_cancelled_appointments=True):
+class Zermelo(SalureConnect):
+    def __init__(self, label: Union[str, List], storage_location, initial_zermelo_extract=False, extract_cancelled_appointments=True):
         """
         Extracts data from source based on the entered parameters
         For documentation see: https://wartburg.zportal.nl/static/swagger/ & https://zermelo.atlassian.net/wiki/display/DEV/API+Entities
@@ -20,8 +20,8 @@ class Zermelo:
         :param initial_zermelo_extract: store the extract as a delta file (true) or not (false)
         :param extract_cancelled_appointments: doesn't get the cancelled appointments by default. Can be changed to an empty string to get the cancelled appointments
         """
-        self.salureconnect_connection = salureconnect_connection
-        credentials = self.salureconnect_connection.get_system_credential(system='zermelo', label=label)
+        super().__init__()
+        credentials = self.get_system_credential(system='zermelo', label=label)
         self.access_token = credentials['token']
         self.url = f"https://{credentials['customer']}.zportal.nl/api/v3/"
         self.storage_location = storage_location
